@@ -111,8 +111,13 @@ class MonThreadDeCalcul(QThread):
 
 
 class StartQT4(QMainWindow):
-    def __init__(self, parent, opts):
-        #Données principales du logiciel : 
+    def __init__(self, parent=None, opts=[], args=[]):
+        """
+        le constructeur reçoit les données principales du logiciel : 
+        @param parent le widget parent, None pour une fenêtre principale
+        @param opts les options de l'invocation bien rangées en tableau
+        @param args les arguments restants après raitement des options
+        """
 
         if "maxi" in str(opts) :
             self.mini=False
@@ -160,14 +165,18 @@ class StartQT4(QMainWindow):
             if ('-d' in o[0]) or ('--debug' in o[0]):
                 self.dbg=Dbg(o[1])
                 self.dbg.p(1,"Niveau de débogage"+o[1])
-        
+        self.args = args
+
         self.cvReader=None
-        self.newVideos=[]            # les vidéos créées par recodage
+
 
 
 
         self.platform = platform.system()
         self.prefs=Preferences(self)
+        if len(self.args) > 0:
+            # le premier argument éventuel est le nom d'une vidéo
+            self.prefs.lastVideo=args[0]
         ####intialise les répertoires
         self._dir()
         defait_icon=os.path.join(self._dir("icones"),"undo.png")
@@ -249,7 +258,7 @@ class StartQT4(QMainWindow):
                 pass
        
 
-    def init_variables(self, opts, filename=""):
+    def init_variables(self, opts, filename=u""):
         self.dbg.p(1,"rentre dans 'init_variables'")
         self.logiciel_acquisition = False
         self.points_ecran={}
@@ -433,9 +442,7 @@ class StartQT4(QMainWindow):
   
         self.init_interface()
 
-        self.ui.pushButton_origine.setEnabled(1)
-        self.ui.checkBox_abscisses.setEnabled(1)
-        self.ui.checkBox_ordonnees.setEnabled(1)
+        
 
         if index_point_actuel :
             index = self.premiere_image
@@ -491,7 +498,13 @@ class StartQT4(QMainWindow):
         self.enableRefaire(False)
         self.affiche_nb_points(1)
         ### Réactiver checkBox_avancees après réinitialisation ###
-        #self.ui.checkBox_avancees.setEnabled(1)
+        self.ui.pushButton_origine.setEnabled(1)
+        self.ui.checkBox_abscisses.setEnabled(1)
+        self.ui.checkBox_ordonnees.setEnabled(1)
+        self.ui.checkBox_auto.setEnabled(1)
+        self.ui.checkBox_abscisses.setCheckState(Qt.Unchecked)
+        self.ui.checkBox_ordonnees.setCheckState(Qt.Unchecked)
+        self.ui.checkBox_auto.setCheckState(Qt.Unchecked)
 
 
         if self.ui.tableWidget:
@@ -731,7 +744,16 @@ class StartQT4(QMainWindow):
         else :
             self.sens_Y = 1
         self.emit(SIGNAL('change_axe_origine()'))
-
+        
+    def check_uncheck_direction_axes(self):
+        if self.sens_X == -1 : 
+            self.ui.checkBox_abscisses.setChecked(1)
+        else : 
+            self.ui.checkBox_abscisses.setChecked(0)
+        if self.sens_Y == -1 : 
+            self.ui.checkBox_ordonnees.setChecked(1)
+        else : 
+            self.ui.checkBox_ordonnees.setChecked(0)
 
     def pointEnMetre(self,p):
         """
@@ -850,41 +872,61 @@ class StartQT4(QMainWindow):
         et recode la vidéo si nécessaire.
         """
         self.dbg.p(1,"rentre dans 'init_cvReader'")
+
         self.cvReader=openCvReader(self.filename)
-        print self.cvReader
-        if not self.cvReader : 
+        time.sleep(0.1)
+        if not self.cvReader.ok and ("/".join(self.filename.split('/')[:-1])!=NEWVID_PATH): #if video is ever encoded, don't get in
+
             sansSuffixe=os.path.basename(self.filename)
             match=re.match("(.*)\.(.*)$",sansSuffixe)
             sansSuffixe=match.group(1)
             dest=os.path.join(NEWVID_PATH,sansSuffixe+".avi")
             self.qmsgboxencode = QMessageBoxEncode(self,dest) #in this, thread to encode
             self.qmsgboxencode.show()
-            return False
-        else : 
-            try: 
-                self.qmsgboxencode.close()
-            except AttributeError:
-                pass
-            
+        else :
             return True
 
     def rouvre_ui(self):
         self.dbg.p(1,"rentre dans 'rouvre_ui'")
         dir_ = self._dir("home")
-        fichier = QFileDialog.getOpenFileName(self,self.tr(QString(u"Ouvrir un projet Pymecavideo")), dir_,self.tr(QString(u"fichiers pymecavideo ( *.mecavideo)")))
+        fichier = QFileDialog.getOpenFileName(self,self.tr(QString(u"Ouvrir un projet Pymecavideo")), dir_,self.tr(QString(u"fichiers pymecavideo(*.csv)")))
         
         if fichier != "":
             self.rouvre(fichier)
 
     def loads(self,s):
         self.dbg.p(1,"rentre dans 'loads'")
-        s=s[1:-1].replace("\n#","\n")
-        self.filename,self.premiere_image,self.echelle_image.longueur_reelle_etalon,self.echelle_image.p1,self.echelle_image.p2,self.deltaT,self.nb_de_points = pickle.loads(s)
+        s=s[1:-2].replace("\n#","\n")
+        
+        self.filename,self.sens_X,self.sens_Y,self.origine,\
+        self.premiere_image,self.echelle_image.longueur_reelle_etalon\
+        ,point,self.deltaT,self.nb_de_points = s.splitlines()[1:-1]
+        self.filename = self.filename.split('=')[-1][1:]
+        self.dbg.p(3,"rentre dans 'loads' %s" %(self.filename))
+        self.sens_X = int(self.sens_X.split()[-1])
+        self.dbg.p(3,"rentre dans 'loads' %s" %(self.sens_X))
+        self.sens_Y = int(self.sens_Y.split()[-1])
+        self.dbg.p(3,"rentre dans 'loads' %s" %(self.sens_Y))
+        self.origine = vecteur(self.origine.split()[-2][1:-1],self.origine.split()[-1][:-1] )
+        self.dbg.p(3,"rentre dans 'loads' %s" %(self.origine))
+        self.premiere_image = int(self.premiere_image.split()[-1])
+        self.dbg.p(3,"rentre dans 'loads' %s" %(self.filename))
+        self.echelle_image.longueur_reelle_etalon = float(self.echelle_image.longueur_reelle_etalon.split()[-2])
+        self.dbg.p(3,"rentre dans 'loads' %s" %(self.filename))
+        self.echelle_image.p1,self.echelle_image.p2 = vecteur(point.split()[-4][1:-1], point.split()[-3][:-1])\
+        ,vecteur(point.split()[-2][1:-1], point.split()[-1][:-1])
+        self.dbg.p(3,"rentre dans 'loads' %s" %(self.filename))
+        self.deltaT = float(self.deltaT.split()[-1])
+        self.dbg.p(3,"rentre dans 'loads' %s" %(self.filename))
+        self.nb_de_points = int(self.nb_de_points.split()[-2])
+        self.dbg.p(3,"rentre dans 'loads' %s" %(self.filename))
+    
         self.init_cvReader()
         
     def rouvre(self,fichier):
         """Open a mecavideo file"""
         self.dbg.p(1,"rentre dans 'rouvre'")
+        
         lignes=open(fichier,"r").readlines()
         i=0
         self.points={}
@@ -892,19 +934,36 @@ class StartQT4(QMainWindow):
         for l in lignes:
             if l[0]=="#":
                 dd+=l
+        self.echelle_image=echelle() # on réinitialise l'échelle
+        self.loads(dd)               # on récupère les données importantes
+        self.check_uncheck_direction_axes() #check or uncheck axes Checkboxes
+        self.init_interface()
+        self.change_axe_ou_origine()
+        for l in lignes:
+            if l[0]=="#":
+                pass
             else:
                 l=l.strip('\t\n')
                 d=l.split("\t")
-                self.points[i]=[d[0]]
-                for j in range(1,len(d),2):
-                    self.points[i].append(vecteur(d[j],d[j+1]))
+                t="%4f" %(float(d[0].replace(",",".")))
+                self.ui.tableWidget.insertRow(i)
+                self.ui.tableWidget.setItem(i,0,QTableWidgetItem(t))
+                self.points[i]=[t]
+                
+                for j in range(1,len(d),2):    
+                    self.points[i].append(vecteur(float(d[j].replace(",","."))*self.echelle_image.longueur_reelle_etalon\
+                    +self.origine.x(),self.origine.y()-float(d[j+1].replace(",","."))*self.echelle_image.longueur_reelle_etalon))  
+                    self.ui.tableWidget.setItem(i,j,QTableWidgetItem(str(float(d[j].replace(",",".")))))
+                    self.ui.tableWidget.setItem(i,j+1,QTableWidgetItem(str(float(d[j+1].replace(",",".")))))
+
+                
                 i+=1
-        self.echelle_image=echelle() # on réinitialise l'échelle
-        self.loads(dd)               # on récupère les données importantes
+        
+                
         # puis on trace le segment entre les points cliqués pour l'échelle
         self.feedbackEchelle(self.echelle_image.p1, self.echelle_image.p2)
         framerate, self.image_max = self.cvReader.recupere_avi_infos()
-        self.dbg.p(3,"In :  'rouvre', framerate, self.image_max = ",framerate, self.image_max )
+        
         self.defini_barre_avancement()
         self.affiche_echelle()       # on met à jour le widget d'échelle
         n=len(self.points.keys())
@@ -920,20 +979,17 @@ class StartQT4(QMainWindow):
         self.affiche_image() # on affiche l'image
         self.debut_capture(departManuel=False)
         # On regénère le tableau d'après les points déjà existants.
-        self.cree_tableau()
-        ligne=0
-        for k in self.points.keys():
-            data=self.points[k]
-            t="%4f" %(float(data[0]))
-            self.ui.tableWidget.insertRow(ligne)
-            self.ui.tableWidget.setItem(ligne,0,QTableWidgetItem(t))
-            i=1
-            for vect in data[1:]:
-                vect=self.pointEnMetre(vect)
-                self.ui.tableWidget.setItem(ligne,i,QTableWidgetItem(str(vect.x())))
-                self.ui.tableWidget.setItem(ligne,i+1,QTableWidgetItem(str(vect.y())))
-                i+=2
-            ligne+=1
+        
+       
+        #for k in self.points.keys():
+            #data=self.points[k]
+            
+            #i=1
+            #for vect in data[1:]:
+                ##vect=self.pointEnMetre(vect)
+                
+                #i+=2
+            #ligne+=1
         self.ui.tableWidget.show()
         # attention à la fonction défaire/refaire : elle est mal initialisée !!!
 
@@ -946,21 +1002,25 @@ class StartQT4(QMainWindow):
         self.dbg.p(1,"rentre dans 'entete_fichier'")
         result=u"""#pymecavideo
 #video = %s
+#sens axe des X = %d
+#sens axe des Y = %d
+#origine de pointage = %s
 #index de depart = %d
 #echelle %5f m pour %5f pixel
 #echelle pointee en %s %s
 #intervalle de temps : %f
 #suivi de %s point(s)
 #%s
-#"""%(self.filename,self.premiere_image,self.echelle_image.longueur_reelle_etalon,self.echelle_image.longueur_pixel_etalon(),self.echelle_image.p1,self.echelle_image.p2,self.deltaT,self.nb_de_points,
-msg)
+#"""%(self.filename,self.sens_X, self.sens_Y,self.origine,self.premiere_image\
+,self.echelle_image.longueur_reelle_etalon,self.echelle_image.longueur_pixel_etalon(),self.echelle_image.p1,self.echelle_image.p2,self.deltaT,self.nb_de_points,msg)
         return result
 
-    def dumps(self):
-        self.dbg.p(1,"rentre dans 'dumps'")
+    #def dumps(self):
+        #self.dbg.p(1,"rentre dans 'dumps'")
        
-        return "#"+pickle.dumps((self.filename,self.premiere_image,self.echelle_image.longueur_reelle_etalon\
-                ,self.echelle_image.p1,self.echelle_image.p2,self.deltaT,self.nb_de_points)).replace("\n","\n#")
+        #return "#"+pickle.dumps((self.filename,self.premiere_image,self.echelle_image.longueur_reelle_etalon\
+                #,self.echelle_image.p1,self.echelle_image.p2,self.deltaT,self.nb_de_points\
+                #,self.origine, self.sens_X,self.sens_Y)).replace("\n","\n#")
 
 
     def enregistre(self, fichier):
@@ -973,27 +1033,29 @@ msg)
         except TypeError:
             pass
         if fichier != "":
-            fichierMecavideo=""+fichier # on force une copie !
-            fichierMecavideo.replace(".csv",".mecavideo")
-            file = open(fichierMecavideo, 'w')
+            #fichierMecavideo=unicode(""+fichier) # on force une copie !
+            ##fichierMecavideo.replace(".csv",".mecavideo")
+            #file = open(fichierMecavideo, 'w')
             liste_des_cles = []
-            try :
-                file.write(self.dumps())
-                for key in self.points:
-                    liste_des_cles.append(key)
-                liste_des_cles.sort()
-                for cle in liste_des_cles:
-                    donnee=self.points[cle]
-                    t=float(donnee[0])
-                    a = "\n%.2f\t" %t
-                    for p in donnee[1:]:
-                        a+= "%d\t" %p.x()
-                        a+= "%d\t" %p.y()
-                    file.write(a)
-            finally:
-                file.close()
-            ################# fin du fichier mecavideo ################
-            file = codecs.open(fichier, 'w', 'utf8')
+            #try :
+                #file.write(self.dumps())
+            for key in self.points:
+                liste_des_cles.append(key)
+                #liste_des_cles.sort()
+                #for cle in liste_des_cles:
+                    #donnee=self.points[cle]
+                    #t=float(donnee[0])
+                    #a = "\n%.2f\t" %t
+                    #for p in donnee[1:]:
+                        #a+= "%d\t" %p.x()
+                        #a+= "%d\t" %p.y()
+                    #file.write(a)
+            #finally:
+                #file.close()
+            ################## fin du fichier mecavideo ################
+            fichier = unicode(fichier)
+            fichier = fichier.encode('utf8')
+            file = codecs.open(fichier, 'w','utf8')
             try :
                 file.write(self.entete_fichier(self.tr(QString(u"temps en seconde, positions en mètre"))))
                 for cle in liste_des_cles:
@@ -1014,6 +1076,7 @@ msg)
         self.dbg.p(1,"rentre dans 'enregistre_ui'")
         if self.points!={}:
             fichier = QFileDialog.getSaveFileName(self,"FileDialog", "data.csv","*.csv *.txt *.asc *.dat")
+            
             self.enregistre(fichier)
 
     def debut_capture(self, departManuel=True):
@@ -1060,6 +1123,11 @@ msg)
             self.ui.comboBox_referentiel.insertItem(-1, self.tr(QString(u"point N°"+" "+str(i+1))))
         self.cree_tableau()
         
+        self.ui.pushButton_origine.setEnabled(0)
+        self.ui.checkBox_abscisses.setEnabled(0)
+        self.ui.checkBox_ordonnees.setEnabled(0)
+        self.ui.checkBox_auto.setEnabled(0)
+        
         #######automatic capture
         if self.ui.checkBox_auto.isChecked():
 
@@ -1218,7 +1286,7 @@ msg)
                             
                 self.dbg.p(3,"origine %s, ref %s" %(str(origine),str(ref)))
         except ZeroDivisionError:
-            print "pb self.tracer_trajectoires"
+            self.dbg.p(1,"ERROR : ZeroDivisionError in Self.tracer_trajectoires")
         self.label_trajectoire.reDraw()
         
         
@@ -1356,8 +1424,7 @@ msg)
         self.dbg.p(1,"rentre dans 'clic_sur_label_video_ajuste_ui'")
 
         self.lance_capture = True
-        self.enableDefaire(len(self.tousLesClics) > 0)
-        self.enableRefaire(self.tousLesClics.nextCount() > 0)
+
 
         if point_attendu==1 : # pour une acquisition sur une nouvelle image
             if len(self.label_video.liste_points) > 0:
@@ -1368,6 +1435,9 @@ msg)
             if len(self.tousLesClics) == len(self.points): #update image only at last point. use to optimise undo/redo fucntions.
                 self.affiche_image()
             self.tracer_trajectoires("absolu")
+            
+        self.enableDefaire(len(self.tousLesClics) > 0)
+        self.enableRefaire(self.tousLesClics.nextCount() > 0)
         
     def stock_coordonnees_image(self, ligne, liste_points, interactif=True, index_image = False):
         """
@@ -1401,7 +1471,7 @@ msg)
                 self.pY[y].append(point)
             else:
                 self.pY[y]=[point]
-	    
+        
             pm=self.pointEnMetre(point)
             self.ui.tableWidget.setItem(ligne,i+1,QTableWidgetItem(str(pm.x())))
             self.ui.tableWidget.setItem(ligne,i+2,QTableWidgetItem(str(pm.y())))
@@ -1537,8 +1607,11 @@ msg)
         Retire les vidéos recodées automatiquement
         """
         self.dbg.p(1,"rentre dans 'nettoieVideosRecodees'")
-        for f in self.newVideos:
-            subprocess.call("rm -f %s" %f, shell=True)
+
+        for fichier in os.listdir(NEWVID_PATH):
+            os.remove(os.path.join(NEWVID_PATH,fichier))
+
+
 
     def verifie_donnees_sauvegardees(self):
         self.dbg.p(1,"rentre dans 'verifie_donnees_sauvegardees'")
@@ -1616,8 +1689,8 @@ msg)
             filename = filename.toUtf8()
             data = filename.data()
             self.filename = data.decode('utf-8')
-            goOn = self.init_cvReader()
-            if goOn : #video is in goo format
+            goOn = self.init_cvReader() 
+            if goOn : #video is in good format
                 
                 self.prefs.lastVideo=self.filename
                 self.init_image()
@@ -1716,18 +1789,19 @@ msg)
         self.dbg.p(1,"rentre dans 'traiteOptions'")
         for opt,val in self.opts:
             if opt in ['-f','--fichier_mecavideo']:
-                if os.path.isfile(val) and os.path.splitext(val)[1] == ".mecavideo":
+                if os.path.isfile(val) and os.path.splitext(val)[1] == ".csv":
                     try:
                         self.rouvre(val)
-                    except:
-                        pass
+                    except AttributeError:
+                        self.dbg.p(1, "Issue in rouvre for this file : attributeerror")
+
                 if os.path.isfile(val) and os.path.splitext(val)[1] == ".avi":
                     self.openTheFile(val)
                     
         
 def usage():
-    print ("Usage : pymecavideo [-f fichier | --fichier_pymecavideo=fichier] [--maxi] [-d | --debug=verbosityLevel(1-3)")
-
+    print ("Usage : pymecavideo [-f fichier | --fichier_pymecavideo=fichier] [--maxi] [-d | --debug=verbosityLevel(1-3)] [nom_de_fichier_video.avi]")
+    
 def run():
     global app
     
@@ -1750,11 +1824,11 @@ def run():
 
     langdir=os.path.join(StartQT4._dir("langues"),
                          "pymecavideo_"+locale)
-    print langdir
+
     if appTranslator.load(langdir):
         b = app.installTranslator(appTranslator)
     
-    windows = StartQT4(None,opts)
+    windows = StartQT4(None,opts,args)
     
     windows.show()
     
